Crate rorm_cli

Crate rorm_cli 

Modules

cli
Reexports for executing the defined cli parser via another
config
Reexport the config This modules holds the definition of the configuration used by [rorm-cli]
init
This module is used for creating a configuration file that can be used by the binary version.
make_migrations
This module handles the creation of migration files
migrate
This module is used for applying migrations