Command

Enum Command 

pub enum Command {
    Init {
        database_config: String,
        force: bool,
        driver: InitDriver,
    },
    MakeMigrations {
        models_file: String,
        migration_dir: String,
        name: Option<String>,
        non_interactive: bool,
        disable_warnings: bool,
    },
    Migrate {
        migration_dir: String,
        database_config: String,
        apply_until: Option<u16>,
    },
    SquashMigrations {
        migration_dir: String,
        first_migration: u16,
        last_migration: u16,
    },
}

Variants



Init

Create the database configuration file

Fields

database_config: String

Path to the database configuration file that should be created.

force: bool

Overwrite the database configuration if it is existent already

driver: InitDriver


MakeMigrations

Tool to create migrations

Fields

models_file: String

Location of the intermediate representation of models.

migration_dir: String

Destination to / from which migrations are written / read.

name: Option<String>

Use this name as migration name instead of generating one.

non_interactive: bool

If set, no questions will be asked.

disable_warnings: bool

If set, no warnings will be printed.



Migrate

Apply migrations

Fields

migration_dir: String

Destination from which migrations are read.

database_config: String

Path to the database configuration file.

apply_until: Option<u16>

Only apply the migrations to (inclusive) the given migration.



SquashMigrations

Squash migrations

Fields

migration_dir: String

Destination to / from which migrations are written / read.

first_migration: u16

First migration to start squashing from.

last_migration: u16

Last migration to squash.