pub fn get_internal_models(models_file: &str) -> Result<InternalModelFormat>Expand description
A helper function to retrieve the internal models from a given location.
models_file: &str: The path to the models file.
pub fn get_internal_models(models_file: &str) -> Result<InternalModelFormat>A helper function to retrieve the internal models from a given location.
models_file: &str: The path to the models file.