Module migrate

Module migrate 

This module is used for applying migrations

Modules

apply
Contains two functions to apply a single migration or a single operation
config

Structs

MigrateOptions
Options for running migrations

Functions

create_last_migration_table
Creates the “last_migration_table” if it doesn’t exist already
get_existing_migrations
Helper function to retrieve a sorted list of migrations in a given directory.
run_migrate
Applies migrations on the given database
run_migrate_custom
Applies migrations on the given database with a given driver