This module is used for applying migrations
Modules
Structs
- Migrate
Options - Options for running migrations
Functions
- create_
last_ migration_ table - Creates the “last_migration_table” if it doesn’t exist already
- get_
existing_ migrations - Helper function to retrieve a sorted list of migrations in a given directory.
- run_
migrate - Applies migrations on the given database
- run_
migrate_ custom - Applies migrations on the given database with a given driver